/**
  * @module steve_tyler
  *
  * ![example image](https://i.ibb.co/7bqPkGJ/PMS-integration-workflow.png "An exemplary image")
  * **Before beginning work it is necessary that:**    * Your organization is registered and
  * activated   * You have participated in a kick­off meeting   * The opening questionnaire has
  * been filled out   * You have your login and password. (Using it you get a unique session
  * `token` that must be used in every request to API as param `jwt`)  [Contact us](https:
  * //bookingpal.com/en/contact-us/) to be registered and get your credentials.  All responses are
  * returned as JSON.  This document covers all the API calls and other methods that can be used to
  * complete Razor-Cloud integration. It is important to note that all parameters are **case
  * sensitive** in this document and should be used as documented.  **Responses:** When a request
  * is successful, a response body will typically be sent back in the form of a JSON object. An
  * exception to this is when a DELETE request is processed, which will result in a successful
  * `200` status and an empty response body.
  */

'use strict';

const Configuration = require('./configuration');
const AuthorizationController = require('./Controllers/AuthorizationController');
const PropertyManagersController = require('./Controllers/PropertyManagersController');
const ProductController = require('./Controllers/ProductController');
const ImagesController = require('./Controllers/ImagesController');
const RatesAndAvailabilityController = require('./Controllers/RatesAndAvailabilityController');
const LOSPricingController = require('./Controllers/LOSPricingController');
const FeeAndTaxController = require('./Controllers/FeeAndTaxController');
const FeeAndTaxMandatoryAtThePropertyLevelController =
  require('./Controllers/FeeAndTaxMandatoryAtThePropertyLevelController');
const YieldsController = require('./Controllers/YieldsController');
const ValidationController = require('./Controllers/ValidationController');
const TestingOfMessageAPICallsController =
  require('./Controllers/TestingOfMessageAPICallsController');
const MessagingController = require('./Controllers/MessagingController');
const RequestToBookController = require('./Controllers/RequestToBookController');
const PushNotificationController = require('./Controllers/PushNotificationController');
const ReservationNotificationsController =
  require('./Controllers/ReservationNotificationsController');
const Authorization = require('./Models/Authorization');
const GetPMslist = require('./Models/GetPMslist');
const PMs = require('./Models/PMs');
const CreatenewUpdatePropertyManagerRequest =
  require('./Models/CreatenewUpdatePropertyManagerRequest');
const Company = require('./Models/Company');
const CompanyDetails = require('./Models/CompanyDetails');
const CompanyAddress = require('./Models/CompanyAddress');
const Phone = require('./Models/Phone');
const Policies = require('./Models/Policies');
const PaymentPolicy = require('./Models/PaymentPolicy');
const SplitPayment = require('./Models/SplitPayment');
const CancellationPolicy = require('./Models/CancellationPolicy');
const ManualPolicy = require('./Models/ManualPolicy');
const ManualPolicies = require('./Models/ManualPolicies');
const FeeTaxMandatory = require('./Models/FeeTaxMandatory');
const Payment = require('./Models/Payment');
const CreditCard = require('./Models/CreditCard');
const PaymentGateways = require('./Models/PaymentGateways');
const PropertyManagerdetailsresponse = require('./Models/PropertyManagerdetailsresponse');
const Productresponse = require('./Models/Productresponse');
const Property = require('./Models/Property');
const Notes = require('./Models/Notes');
const DescriptionTextModel = require('./Models/DescriptionTextModel');
const Text = require('./Models/Text');
const AttributesWithQuantity = require('./Models/AttributesWithQuantity');
const BedroomConfiguration = require('./Models/BedroomConfiguration');
const Bedroom = require('./Models/Bedroom');
const Beds = require('./Models/Beds');
const Bed = require('./Models/Bed');
const Policy = require('./Models/Policy');
const InternetPolicy = require('./Models/InternetPolicy');
const ParkingPolicy = require('./Models/ParkingPolicy');
const PetPolicy = require('./Models/PetPolicy');
const Location = require('./Models/Location');
const CreateUpdatePropertyRequest = require('./Models/CreateUpdatePropertyRequest');
const NearbyAmenity = require('./Models/NearbyAmenity');
const APIResponsewithoutData = require('./Models/APIResponsewithoutData');
const PropertyListRequest = require('./Models/PropertyListRequest');
const GetimagelistbyproductID = require('./Models/GetimagelistbyproductID');
const Image = require('./Models/Image');
const CreateimagesRequest = require('./Models/CreateimagesRequest');
const ImageUrlforCreate = require('./Models/ImageUrlforCreate');
const DeletelistofimagesRequest = require('./Models/DeletelistofimagesRequest');
const ImageUrlList = require('./Models/ImageUrlList');
const RatesAvailabilityresponse = require('./Models/RatesAvailabilityresponse');
const RatesAvailability = require('./Models/RatesAvailability');
const Rate = require('./Models/Rate');
const MinStayModel = require('./Models/MinStayModel');
const MaxStayModel = require('./Models/MaxStayModel');
const Restriction = require('./Models/Restriction');
const CheckIn = require('./Models/CheckIn');
const CheckOut = require('./Models/CheckOut');
const AvailabilityModel = require('./Models/AvailabilityModel');
const CreateandupdateratesandavailabilityRequest =
  require('./Models/CreateandupdateratesandavailabilityRequest');
const AvailableCount = require('./Models/AvailableCount');
const CreateandupdateLOSRequest = require('./Models/CreateandupdateLOSRequest');
const LosRatesProduct = require('./Models/LosRatesProduct');
const LosRate = require('./Models/LosRate');
const LOSratesresponse = require('./Models/LOSratesresponse');
const FeeTaxResponse = require('./Models/FeeTaxResponse');
const FeeTax = require('./Models/FeeTax');
const Fee = require('./Models/Fee');
const Taxes = require('./Models/Taxes');
const CreatefeeandtaxRequest = require('./Models/CreatefeeandtaxRequest');
const FeeTaxValidationSettingResponse = require('./Models/FeeTaxValidationSettingResponse');
const FeeTaxValidationSettings = require('./Models/FeeTaxValidationSettings');
const FeeTaxMandatorySetting = require('./Models/FeeTaxMandatorySetting');
const SetfeeandtaxvalidationsettingRequest =
  require('./Models/SetfeeandtaxvalidationsettingRequest');
const Yieldresponse = require('./Models/Yieldresponse');
const TransportYield = require('./Models/TransportYield');
const Yield = require('./Models/Yield');
const CreateYieldRequest = require('./Models/CreateYieldRequest');
const ValidationforListofpropertiesRequest =
  require('./Models/ValidationforListofpropertiesRequest');
const ValidationPropertyIDsList = require('./Models/ValidationPropertyIDsList');
const ThreadsModel = require('./Models/ThreadsModel');
const Thread = require('./Models/Thread');
const MessageRequestFromSupplier = require('./Models/MessageRequestFromSupplier');
const GetmessagethreadsResponse = require('./Models/GetmessagethreadsResponse');
const GetmessagelistforspecificthreadResponse =
  require('./Models/GetmessagelistforspecificthreadResponse');
const MessagesModel = require('./Models/MessagesModel');
const MessageModel = require('./Models/MessageModel');
const PostnewmessageforspecificthreadRequest =
  require('./Models/PostnewmessageforspecificthreadRequest');
const RequesttoBookAnswerfromPMSRequest = require('./Models/RequesttoBookAnswerfromPMSRequest');
const FunctionsRequestToBook = require('./Models/FunctionsRequestToBook');
const RequesttoBookTestRequest = require('./Models/RequesttoBookTestRequest');
const FunctionsRequestToBookTest = require('./Models/FunctionsRequestToBookTest');
const PushNotificationLinksRequest = require('./Models/PushNotificationLinksRequest');
const PushNotificationLinksModel = require('./Models/PushNotificationLinksModel');
const PushNotificationLinksResponse = require('./Models/PushNotificationLinksResponse');
const PaymentPolicyTypeEnum = require('./Models/PaymentPolicyTypeEnum');
const DepositTypeEnum = require('./Models/DepositTypeEnum');
const TypeEnum = require('./Models/TypeEnum');
const CancellationPolicyTypeEnum = require('./Models/CancellationPolicyTypeEnum');
const ManualPolicyTypeEnum = require('./Models/ManualPolicyTypeEnum');
const PaymentTypeEnum = require('./Models/PaymentTypeEnum');
const CreditCardTypeEnum = require('./Models/CreditCardTypeEnum');
const CreditCardListEnum = require('./Models/CreditCardListEnum');
const PaymentGatewaysTypeEnum = require('./Models/PaymentGatewaysTypeEnum');
const BedroomTypeEnum = require('./Models/BedroomTypeEnum');
const KindofInternetTypeEnum = require('./Models/KindofInternetTypeEnum');
const AvailableInternetEnum = require('./Models/AvailableInternetEnum');
const LocatedParkingTypeEnum = require('./Models/LocatedParkingTypeEnum');
const TimeCostParkingEnum = require('./Models/TimeCostParkingEnum');
const ReservationParkingTypeEnum = require('./Models/ReservationParkingTypeEnum');
const AllowedPetsTypeEnum = require('./Models/AllowedPetsTypeEnum');
const FeetaxTypeEnum = require('./Models/FeetaxTypeEnum');
const FeeUnitEnum = require('./Models/FeeUnitEnum');
const FeeEntityTypeEnum = require('./Models/FeeEntityTypeEnum');
const FeeTypeEnum = require('./Models/FeeTypeEnum');
const TaxisTypeEnum = require('./Models/TaxisTypeEnum');
const WeekendParamEnum = require('./Models/WeekendParamEnum');
const YieldmodifierEnum = require('./Models/YieldmodifierEnum');
const FeeValueTypeEnum = require('./Models/FeeValueTypeEnum');
const ChannelABBEnum = require('./Models/ChannelABBEnum');
const SpaceUnitEnum = require('./Models/SpaceUnitEnum');
const UserEnum = require('./Models/UserEnum');
const RequestToBookTypeEnum = require('./Models/RequestToBookTypeEnum');
const RequestToBookDeclineReasonTypeEnum = require('./Models/RequestToBookDeclineReasonTypeEnum');
const RequesttoBookTestActionEnum = require('./Models/RequesttoBookTestActionEnum');
const NearbyAmenitiesEnum = require('./Models/NearbyAmenitiesEnum');
const PropertyTypesEnum = require('./Models/PropertyTypesEnum');
const AmenityTypesEnum = require('./Models/AmenityTypesEnum');
const BedConfigurationEnum = require('./Models/BedConfigurationEnum');
const ImageTagsEnum = require('./Models/ImageTagsEnum');
const Reservationnotificationobject = require('./Models/Reservationnotificationobject');
const ReservationpushResponse = require('./Models/ReservationpushResponse');
const ReservationFeeNotificationModel = require('./Models/ReservationFeeNotificationModel');
const ReservationTaxNotificationModel = require('./Models/ReservationTaxNotificationModel');
const ReservationRateNotifcationModel = require('./Models/ReservationRateNotifcationModel');
const ReservationCommissionsNotificationModel =
  require('./Models/ReservationCommissionsNotificationModel');
const CancelReservationnotificationobject = require('./Models/CancelReservationnotificationobject');
const ReservationGetResponse = require('./Models/ReservationGetResponse');
const ValidationAsynchronouspushmessagerequest =
  require('./Models/ValidationAsynchronouspushmessagerequest');
const AsynchronouspushmessagetypeEnum = require('./Models/AsynchronouspushmessagetypeEnum');
const AsynchronousValidationmodel = require('./Models/AsynchronousValidationmodel');
const RequestToBookRequestModel = require('./Models/RequestToBookRequestModel');
const RequestToBookCancelRequestModel = require('./Models/RequestToBookCancelRequestModel');
const MultiUnitEnum = require('./Models/MultiUnitEnum');
const APIException = require('./Exceptions/APIException');


const initializer = {
    // functional components of steve_tyler
    Configuration,
    // controllers of steve_tyler
    AuthorizationController,
    PropertyManagersController,
    ProductController,
    ImagesController,
    RatesAndAvailabilityController,
    LOSPricingController,
    FeeAndTaxController,
    FeeAndTaxMandatoryAtThePropertyLevelController,
    YieldsController,
    ValidationController,
    TestingOfMessageAPICallsController,
    MessagingController,
    RequestToBookController,
    PushNotificationController,
    ReservationNotificationsController,
    // models of steve_tyler
    Authorization,
    GetPMslist,
    PMs,
    CreatenewUpdatePropertyManagerRequest,
    Company,
    CompanyDetails,
    CompanyAddress,
    Phone,
    Policies,
    PaymentPolicy,
    SplitPayment,
    CancellationPolicy,
    ManualPolicy,
    ManualPolicies,
    FeeTaxMandatory,
    Payment,
    CreditCard,
    PaymentGateways,
    PropertyManagerdetailsresponse,
    Productresponse,
    Property,
    Notes,
    DescriptionTextModel,
    Text,
    AttributesWithQuantity,
    BedroomConfiguration,
    Bedroom,
    Beds,
    Bed,
    Policy,
    InternetPolicy,
    ParkingPolicy,
    PetPolicy,
    Location,
    CreateUpdatePropertyRequest,
    NearbyAmenity,
    APIResponsewithoutData,
    PropertyListRequest,
    GetimagelistbyproductID,
    Image,
    CreateimagesRequest,
    ImageUrlforCreate,
    DeletelistofimagesRequest,
    ImageUrlList,
    RatesAvailabilityresponse,
    RatesAvailability,
    Rate,
    MinStayModel,
    MaxStayModel,
    Restriction,
    CheckIn,
    CheckOut,
    AvailabilityModel,
    CreateandupdateratesandavailabilityRequest,
    AvailableCount,
    CreateandupdateLOSRequest,
    LosRatesProduct,
    LosRate,
    LOSratesresponse,
    FeeTaxResponse,
    FeeTax,
    Fee,
    Taxes,
    CreatefeeandtaxRequest,
    FeeTaxValidationSettingResponse,
    FeeTaxValidationSettings,
    FeeTaxMandatorySetting,
    SetfeeandtaxvalidationsettingRequest,
    Yieldresponse,
    TransportYield,
    Yield,
    CreateYieldRequest,
    ValidationforListofpropertiesRequest,
    ValidationPropertyIDsList,
    ThreadsModel,
    Thread,
    MessageRequestFromSupplier,
    GetmessagethreadsResponse,
    GetmessagelistforspecificthreadResponse,
    MessagesModel,
    MessageModel,
    PostnewmessageforspecificthreadRequest,
    RequesttoBookAnswerfromPMSRequest,
    FunctionsRequestToBook,
    RequesttoBookTestRequest,
    FunctionsRequestToBookTest,
    PushNotificationLinksRequest,
    PushNotificationLinksModel,
    PushNotificationLinksResponse,
    PaymentPolicyTypeEnum,
    DepositTypeEnum,
    TypeEnum,
    CancellationPolicyTypeEnum,
    ManualPolicyTypeEnum,
    PaymentTypeEnum,
    CreditCardTypeEnum,
    CreditCardListEnum,
    PaymentGatewaysTypeEnum,
    BedroomTypeEnum,
    KindofInternetTypeEnum,
    AvailableInternetEnum,
    LocatedParkingTypeEnum,
    TimeCostParkingEnum,
    ReservationParkingTypeEnum,
    AllowedPetsTypeEnum,
    FeetaxTypeEnum,
    FeeUnitEnum,
    FeeEntityTypeEnum,
    FeeTypeEnum,
    TaxisTypeEnum,
    WeekendParamEnum,
    YieldmodifierEnum,
    FeeValueTypeEnum,
    ChannelABBEnum,
    SpaceUnitEnum,
    UserEnum,
    RequestToBookTypeEnum,
    RequestToBookDeclineReasonTypeEnum,
    RequesttoBookTestActionEnum,
    NearbyAmenitiesEnum,
    PropertyTypesEnum,
    AmenityTypesEnum,
    BedConfigurationEnum,
    ImageTagsEnum,
    Reservationnotificationobject,
    ReservationpushResponse,
    ReservationFeeNotificationModel,
    ReservationTaxNotificationModel,
    ReservationRateNotifcationModel,
    ReservationCommissionsNotificationModel,
    CancelReservationnotificationobject,
    ReservationGetResponse,
    ValidationAsynchronouspushmessagerequest,
    AsynchronouspushmessagetypeEnum,
    AsynchronousValidationmodel,
    RequestToBookRequestModel,
    RequestToBookCancelRequestModel,
    MultiUnitEnum,
    // exceptions of steve_tyler
    APIException,
};

module.exports = initializer;
